@@ -30,7 +30,7 @@ sub validate {
         $found++;
 
         unless ( $value =~ /^\d+$/ ) {
-            $self->add_error( "Invalid value for '$sub'" );
+            $self->add_error( "Invalid value for '[_1]", $sub );
             return;
         }
         $date{ $sub } = $value;
@@ -49,7 +49,7 @@ sub validate {
     eval {  $dt = DateTime->new( %date, time_zone => 'floating' ) };
 
     if ( $@ ) {
-        $self->add_error( "Invalid date [$@]" );
+        $self->add_error( "Invalid date ([_1])", "$@" );
         return;
     }
 
